diff -Nur vx/xen-4.5.0/xen/drivers/passthrough/iommu.c xen-4.5.0/xen/drivers/passthrough/iommu.c
--- vx/xen-4.5.0/xen/drivers/passthrough/iommu.c	2015-01-12 11:53:24.000000000 -0500
+++ xen-4.5.0/xen/drivers/passthrough/iommu.c	2015-01-20 13:05:08.648883272 -0500
@@ -39,6 +39,7 @@
  *   no-snoop                   Disable VT-d Snoop Control
  *   no-qinval                  Disable VT-d Queued Invalidation
  *   no-intremap                Disable VT-d Interrupt Remapping
+ *   no-igd-vtd                 Disable the Intel IGD VT-d engine
  */
 custom_param("iommu", parse_iommu_param);
 bool_t __initdata iommu_enable = 1;
@@ -51,6 +52,7 @@
 bool_t __read_mostly iommu_snoop = 1;
 bool_t __read_mostly iommu_qinval = 1;
 bool_t __read_mostly iommu_intremap = 1;
+bool_t __read_mostly iommu_igdvtd = 1;
 bool_t __read_mostly iommu_hap_pt_share = 1;
 bool_t __read_mostly iommu_debug;
 bool_t __read_mostly amd_iommu_perdev_intremap = 1;
@@ -95,6 +97,8 @@
             iommu_qinval = val;
         else if ( !strcmp(s, "intremap") )
             iommu_intremap = val;
+        else if ( !strcmp(s, "igd-vtd") )
+            iommu_igdvtd = 0;
         else if ( !strcmp(s, "debug") )
         {
             iommu_debug = val;
diff -Nur vx/xen-4.5.0/xen/drivers/passthrough/vtd/iommu.c xen-4.5.0/xen/drivers/passthrough/vtd/iommu.c
--- vx/xen-4.5.0/xen/drivers/passthrough/vtd/iommu.c	2015-01-12 11:53:24.000000000 -0500
+++ xen-4.5.0/xen/drivers/passthrough/vtd/iommu.c	2015-01-20 13:18:09.893708301 -0500
@@ -708,17 +708,26 @@
     u32 sts;
     unsigned long flags;
     struct iommu *iommu = drhd->iommu;
-
-    if ( is_igd_drhd(drhd) && !is_igd_vt_enabled_quirk() ) 
+  
+    if ( is_igd_drhd(drhd) )
     {
-        if ( force_iommu )
-            panic("BIOS did not enable IGD for VT properly, crash Xen for security purpose");
-        else
+        if ( iommu_igdvtd == 0 )
         {
-            dprintk(XENLOG_WARNING VTDPREFIX,
-                    "BIOS did not enable IGD for VT properly.  Disabling IGD VT-d engine.\n");
+            dprintk(XENLOG_WARNING VTDPREFIX, 
+                    "Intentionally not enabling VT-d engine on IGD by user request\n");
             return;
         }
+        if ( !is_igd_vt_enabled_quirk() ) 
+        {
+            if ( force_iommu )
+                panic("BIOS did not enable IGD for VT properly, crash Xen for security purpose!\n");
+            else
+            {
+                dprintk(XENLOG_WARNING VTDPREFIX,
+                        "BIOS did not enable IGD for VT properly.  Disabling IGD VT-d engine.\n");
+                return;
+            }
+        }
     }
 
     /* apply platform specific errata workarounds */
diff -Nur vx/xen-4.5.0/xen/include/xen/iommu.h xen-4.5.0/xen/include/xen/iommu.h
--- vx/xen-4.5.0/xen/include/xen/iommu.h	2015-01-12 11:53:24.000000000 -0500
+++ xen-4.5.0/xen/include/xen/iommu.h	2015-01-20 13:19:19.357424922 -0500
@@ -30,7 +30,7 @@
 extern bool_t iommu_enable, iommu_enabled;
 extern bool_t force_iommu, iommu_verbose;
 extern bool_t iommu_workaround_bios_bug, iommu_passthrough;
-extern bool_t iommu_snoop, iommu_qinval, iommu_intremap;
+extern bool_t iommu_snoop, iommu_qinval, iommu_intremap, iommu_igdvtd;
 extern bool_t iommu_hap_pt_share;
 extern bool_t iommu_debug;
 extern bool_t amd_iommu_perdev_intremap;
